@@ -648,44 +648,3 @@ class ProjectApps(Controller):
                 raise
 
         self.app.render(response.data['message'], renderer_type='text')
-
-
-class Addons(Controller):
-    class Meta:
-        label = 'addon'
-        stacked_type = 'nested'
-        stacked_on = 'base'
-        description = 'this is the addon controller namespace'
-
-    @ex(
-        help='Addon List Command',
-        arguments=[
-            (
-                ['project_id'],
-                {
-                    'help': 'Project ID',
-                    'action': 'store',
-                },
-            ),
-            (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
-        ],
-    )
-    def list(self):
-        response = self.app.client.get_addons(
-            project_id=int(self.app.pargs.project_id), project_app_id=int(self.app.pargs.project_app_id)
-        )
-        self.app.render(
-            data=response.data,
-            rows=response.data.get('results', []),
-            headers={
-                "pk": "ID",
-                "addon_type_relation": "Addon Type Relation",
-                "project_app": "Project App ID",
-                "is_alive": "Is Alive",
-                "config": "Config",
-                "remote_url": "Remote URL",
-                "status": "Status",
-                "is_provisioned": "Is Provisioned",
-            },
-            is_succeed=response.is_succeed,
-        )
