@@ -11,7 +11,7 @@ from akinoncli.controllers.applications import Applications, ApplicationTypes
 from akinoncli.controllers.auth import Auth
 from akinoncli.controllers.base import Base
 from akinoncli.controllers.clusters import KubeMetricMonitor
-from akinoncli.controllers.projects import Addons, ProjectApps, Projects
+from akinoncli.controllers.projects import ProjectApps, Projects
 from akinoncli.controllers.public_keys import PublicKeys
 from akinoncli.core.exc import AkinonCLIError, AkinonCLIWarning
 from akinoncli.core.version import get_version
@@ -94,7 +94,6 @@ class AkinonCLI(App):
             # Roles,
             Domains,
             Certificates,
-            Addons,
             KubeMetricMonitor,
         ]
 
